@@ -22,6 +22,8 @@
 #include "private/decorationbridge.h"
 #include "decoration.h"
 
+#include <QColor>
+
 namespace KDecoration2
 {
 
@@ -67,9 +69,42 @@ DELEGATE(Qt::Edges, adjacentScreenEdges)
 
 #undef DELEGATE
 
+bool DecoratedClient::hasApplicationMenu() const
+{
+    if (const auto *appMenuEnabledPrivate = dynamic_cast<ApplicationMenuEnabledDecoratedClientPrivate *>(d.get())) {
+        return appMenuEnabledPrivate->hasApplicationMenu();
+    }
+    return false;
+}
+
+bool DecoratedClient::isApplicationMenuActive() const
+{
+    if (const auto *appMenuEnabledPrivate = dynamic_cast<ApplicationMenuEnabledDecoratedClientPrivate *>(d.get())) {
+        return appMenuEnabledPrivate->isApplicationMenuActive();
+    }
+    return false;
+}
+
 QPointer< Decoration > DecoratedClient::decoration() const
 {
     return QPointer<Decoration>(d->decoration());
 }
 
+QColor DecoratedClient::color(QPalette::ColorGroup group, QPalette::ColorRole role) const
+{
+    return d->palette().color(group, role);
+}
+
+QColor DecoratedClient::color(ColorGroup group, ColorRole role) const
+{
+    return d->color(group, role);
+}
+
+void DecoratedClient::showApplicationMenu(int actionId)
+{
+    if (auto *appMenuEnabledPrivate = dynamic_cast<ApplicationMenuEnabledDecoratedClientPrivate *>(d.get())) {
+        appMenuEnabledPrivate->showApplicationMenu(actionId);
+    }
+}
+
 } // namespace
